# coding: utf-8

# flake8: noqa
"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from herdsdk.models.allowed_attribute_values_create_request import AllowedAttributeValuesCreateRequest
from herdsdk.models.allowed_attribute_values_delete_request import AllowedAttributeValuesDeleteRequest
from herdsdk.models.allowed_attribute_values_information import AllowedAttributeValuesInformation
from herdsdk.models.attribute import Attribute
from herdsdk.models.attribute_definition import AttributeDefinition
from herdsdk.models.attribute_value_filter import AttributeValueFilter
from herdsdk.models.attribute_value_list import AttributeValueList
from herdsdk.models.attribute_value_list_create_request import AttributeValueListCreateRequest
from herdsdk.models.attribute_value_list_key import AttributeValueListKey
from herdsdk.models.attribute_value_list_keys import AttributeValueListKeys
from herdsdk.models.aws_credential import AwsCredential
from herdsdk.models.build_information import BuildInformation
from herdsdk.models.business_object_data import BusinessObjectData
from herdsdk.models.business_object_data_attribute import BusinessObjectDataAttribute
from herdsdk.models.business_object_data_attribute_create_request import BusinessObjectDataAttributeCreateRequest
from herdsdk.models.business_object_data_attribute_key import BusinessObjectDataAttributeKey
from herdsdk.models.business_object_data_attribute_keys import BusinessObjectDataAttributeKeys
from herdsdk.models.business_object_data_attribute_update_request import BusinessObjectDataAttributeUpdateRequest
from herdsdk.models.business_object_data_attributes_update_request import BusinessObjectDataAttributesUpdateRequest
from herdsdk.models.business_object_data_availability import BusinessObjectDataAvailability
from herdsdk.models.business_object_data_availability_collection_request import BusinessObjectDataAvailabilityCollectionRequest
from herdsdk.models.business_object_data_availability_collection_response import BusinessObjectDataAvailabilityCollectionResponse
from herdsdk.models.business_object_data_availability_request import BusinessObjectDataAvailabilityRequest
from herdsdk.models.business_object_data_create_request import BusinessObjectDataCreateRequest
from herdsdk.models.business_object_data_ddl import BusinessObjectDataDdl
from herdsdk.models.business_object_data_ddl_collection_request import BusinessObjectDataDdlCollectionRequest
from herdsdk.models.business_object_data_ddl_collection_response import BusinessObjectDataDdlCollectionResponse
from herdsdk.models.business_object_data_ddl_output_format_enum import BusinessObjectDataDdlOutputFormatEnum
from herdsdk.models.business_object_data_ddl_request import BusinessObjectDataDdlRequest
from herdsdk.models.business_object_data_download_credential import BusinessObjectDataDownloadCredential
from herdsdk.models.business_object_data_invalidate_unregistered_request import BusinessObjectDataInvalidateUnregisteredRequest
from herdsdk.models.business_object_data_invalidate_unregistered_response import BusinessObjectDataInvalidateUnregisteredResponse
from herdsdk.models.business_object_data_key import BusinessObjectDataKey
from herdsdk.models.business_object_data_keys import BusinessObjectDataKeys
from herdsdk.models.business_object_data_legal_hold_update_request import BusinessObjectDataLegalHoldUpdateRequest
from herdsdk.models.business_object_data_notification_filter import BusinessObjectDataNotificationFilter
from herdsdk.models.business_object_data_notification_registration import BusinessObjectDataNotificationRegistration
from herdsdk.models.business_object_data_notification_registration_create_request import BusinessObjectDataNotificationRegistrationCreateRequest
from herdsdk.models.business_object_data_notification_registration_keys import BusinessObjectDataNotificationRegistrationKeys
from herdsdk.models.business_object_data_notification_registration_update_request import BusinessObjectDataNotificationRegistrationUpdateRequest
from herdsdk.models.business_object_data_parents_update_request import BusinessObjectDataParentsUpdateRequest
from herdsdk.models.business_object_data_partitions import BusinessObjectDataPartitions
from herdsdk.models.business_object_data_partitions_request import BusinessObjectDataPartitionsRequest
from herdsdk.models.business_object_data_retention_information_update_request import BusinessObjectDataRetentionInformationUpdateRequest
from herdsdk.models.business_object_data_retry_storage_policy_transition_request import BusinessObjectDataRetryStoragePolicyTransitionRequest
from herdsdk.models.business_object_data_search_filter import BusinessObjectDataSearchFilter
from herdsdk.models.business_object_data_search_key import BusinessObjectDataSearchKey
from herdsdk.models.business_object_data_search_request import BusinessObjectDataSearchRequest
from herdsdk.models.business_object_data_search_result import BusinessObjectDataSearchResult
from herdsdk.models.business_object_data_status import BusinessObjectDataStatus
from herdsdk.models.business_object_data_status_change_event import BusinessObjectDataStatusChangeEvent
from herdsdk.models.business_object_data_status_information import BusinessObjectDataStatusInformation
from herdsdk.models.business_object_data_status_update_request import BusinessObjectDataStatusUpdateRequest
from herdsdk.models.business_object_data_status_update_response import BusinessObjectDataStatusUpdateResponse
from herdsdk.models.business_object_data_storage_file_key import BusinessObjectDataStorageFileKey
from herdsdk.models.business_object_data_storage_files_create_request import BusinessObjectDataStorageFilesCreateRequest
from herdsdk.models.business_object_data_storage_files_create_response import BusinessObjectDataStorageFilesCreateResponse
from herdsdk.models.business_object_data_storage_unit_create_request import BusinessObjectDataStorageUnitCreateRequest
from herdsdk.models.business_object_data_storage_unit_create_response import BusinessObjectDataStorageUnitCreateResponse
from herdsdk.models.business_object_data_storage_unit_key import BusinessObjectDataStorageUnitKey
from herdsdk.models.business_object_data_storage_unit_status_update_request import BusinessObjectDataStorageUnitStatusUpdateRequest
from herdsdk.models.business_object_data_storage_unit_status_update_response import BusinessObjectDataStorageUnitStatusUpdateResponse
from herdsdk.models.business_object_data_upload_credential import BusinessObjectDataUploadCredential
from herdsdk.models.business_object_data_version import BusinessObjectDataVersion
from herdsdk.models.business_object_data_versions import BusinessObjectDataVersions
from herdsdk.models.business_object_definition import BusinessObjectDefinition
from herdsdk.models.business_object_definition_change_event import BusinessObjectDefinitionChangeEvent
from herdsdk.models.business_object_definition_column import BusinessObjectDefinitionColumn
from herdsdk.models.business_object_definition_column_change_event import BusinessObjectDefinitionColumnChangeEvent
from herdsdk.models.business_object_definition_column_create_request import BusinessObjectDefinitionColumnCreateRequest
from herdsdk.models.business_object_definition_column_key import BusinessObjectDefinitionColumnKey
from herdsdk.models.business_object_definition_column_keys import BusinessObjectDefinitionColumnKeys
from herdsdk.models.business_object_definition_column_search_filter import BusinessObjectDefinitionColumnSearchFilter
from herdsdk.models.business_object_definition_column_search_key import BusinessObjectDefinitionColumnSearchKey
from herdsdk.models.business_object_definition_column_search_request import BusinessObjectDefinitionColumnSearchRequest
from herdsdk.models.business_object_definition_column_search_response import BusinessObjectDefinitionColumnSearchResponse
from herdsdk.models.business_object_definition_column_update_request import BusinessObjectDefinitionColumnUpdateRequest
from herdsdk.models.business_object_definition_create_request import BusinessObjectDefinitionCreateRequest
from herdsdk.models.business_object_definition_description_suggestion import BusinessObjectDefinitionDescriptionSuggestion
from herdsdk.models.business_object_definition_description_suggestion_acceptance_request import BusinessObjectDefinitionDescriptionSuggestionAcceptanceRequest
from herdsdk.models.business_object_definition_description_suggestion_create_request import BusinessObjectDefinitionDescriptionSuggestionCreateRequest
from herdsdk.models.business_object_definition_description_suggestion_key import BusinessObjectDefinitionDescriptionSuggestionKey
from herdsdk.models.business_object_definition_description_suggestion_keys import BusinessObjectDefinitionDescriptionSuggestionKeys
from herdsdk.models.business_object_definition_description_suggestion_search_filter import BusinessObjectDefinitionDescriptionSuggestionSearchFilter
from herdsdk.models.business_object_definition_description_suggestion_search_key import BusinessObjectDefinitionDescriptionSuggestionSearchKey
from herdsdk.models.business_object_definition_description_suggestion_search_request import BusinessObjectDefinitionDescriptionSuggestionSearchRequest
from herdsdk.models.business_object_definition_description_suggestion_search_response import BusinessObjectDefinitionDescriptionSuggestionSearchResponse
from herdsdk.models.business_object_definition_description_suggestion_update_request import BusinessObjectDefinitionDescriptionSuggestionUpdateRequest
from herdsdk.models.business_object_definition_descriptive_information_update_request import BusinessObjectDefinitionDescriptiveInformationUpdateRequest
from herdsdk.models.business_object_definition_index_response import BusinessObjectDefinitionIndexResponse
from herdsdk.models.business_object_definition_key import BusinessObjectDefinitionKey
from herdsdk.models.business_object_definition_keys import BusinessObjectDefinitionKeys
from herdsdk.models.business_object_definition_sample_data_file_key import BusinessObjectDefinitionSampleDataFileKey
from herdsdk.models.business_object_definition_search_filter import BusinessObjectDefinitionSearchFilter
from herdsdk.models.business_object_definition_search_key import BusinessObjectDefinitionSearchKey
from herdsdk.models.business_object_definition_search_request import BusinessObjectDefinitionSearchRequest
from herdsdk.models.business_object_definition_search_response import BusinessObjectDefinitionSearchResponse
from herdsdk.models.business_object_definition_subject_matter_expert import BusinessObjectDefinitionSubjectMatterExpert
from herdsdk.models.business_object_definition_subject_matter_expert_create_request import BusinessObjectDefinitionSubjectMatterExpertCreateRequest
from herdsdk.models.business_object_definition_subject_matter_expert_key import BusinessObjectDefinitionSubjectMatterExpertKey
from herdsdk.models.business_object_definition_subject_matter_expert_keys import BusinessObjectDefinitionSubjectMatterExpertKeys
from herdsdk.models.business_object_definition_tag import BusinessObjectDefinitionTag
from herdsdk.models.business_object_definition_tag_create_request import BusinessObjectDefinitionTagCreateRequest
from herdsdk.models.business_object_definition_tag_key import BusinessObjectDefinitionTagKey
from herdsdk.models.business_object_definition_tag_keys import BusinessObjectDefinitionTagKeys
from herdsdk.models.business_object_definition_update_request import BusinessObjectDefinitionUpdateRequest
from herdsdk.models.business_object_format import BusinessObjectFormat
from herdsdk.models.business_object_format_attribute_definitions_update_request import BusinessObjectFormatAttributeDefinitionsUpdateRequest
from herdsdk.models.business_object_format_attributes_update_request import BusinessObjectFormatAttributesUpdateRequest
from herdsdk.models.business_object_format_create_request import BusinessObjectFormatCreateRequest
from herdsdk.models.business_object_format_ddl import BusinessObjectFormatDdl
from herdsdk.models.business_object_format_ddl_collection_request import BusinessObjectFormatDdlCollectionRequest
from herdsdk.models.business_object_format_ddl_collection_response import BusinessObjectFormatDdlCollectionResponse
from herdsdk.models.business_object_format_ddl_request import BusinessObjectFormatDdlRequest
from herdsdk.models.business_object_format_external_interface import BusinessObjectFormatExternalInterface
from herdsdk.models.business_object_format_external_interface_create_request import BusinessObjectFormatExternalInterfaceCreateRequest
from herdsdk.models.business_object_format_external_interface_descriptive_information import BusinessObjectFormatExternalInterfaceDescriptiveInformation
from herdsdk.models.business_object_format_external_interface_key import BusinessObjectFormatExternalInterfaceKey
from herdsdk.models.business_object_format_key import BusinessObjectFormatKey
from herdsdk.models.business_object_format_keys import BusinessObjectFormatKeys
from herdsdk.models.business_object_format_legal_hold_update_request import BusinessObjectFormatLegalHoldUpdateRequest
from herdsdk.models.business_object_format_parents_update_request import BusinessObjectFormatParentsUpdateRequest
from herdsdk.models.business_object_format_record_flag_update_request import BusinessObjectFormatRecordFlagUpdateRequest
from herdsdk.models.business_object_format_retention_information_update_request import BusinessObjectFormatRetentionInformationUpdateRequest
from herdsdk.models.business_object_format_schema_backwards_compatibility_update_request import BusinessObjectFormatSchemaBackwardsCompatibilityUpdateRequest
from herdsdk.models.business_object_format_update_request import BusinessObjectFormatUpdateRequest
from herdsdk.models.configuration_entry import ConfigurationEntry
from herdsdk.models.configuration_entry_keys import ConfigurationEntryKeys
from herdsdk.models.configuration_file import ConfigurationFile
from herdsdk.models.configuration_files import ConfigurationFiles
from herdsdk.models.custom_ddl import CustomDdl
from herdsdk.models.custom_ddl_create_request import CustomDdlCreateRequest
from herdsdk.models.custom_ddl_key import CustomDdlKey
from herdsdk.models.custom_ddl_keys import CustomDdlKeys
from herdsdk.models.custom_ddl_update_request import CustomDdlUpdateRequest
from herdsdk.models.data_provider import DataProvider
from herdsdk.models.data_provider_create_request import DataProviderCreateRequest
from herdsdk.models.data_provider_key import DataProviderKey
from herdsdk.models.data_provider_keys import DataProviderKeys
from herdsdk.models.descriptive_business_object_format import DescriptiveBusinessObjectFormat
from herdsdk.models.descriptive_business_object_format_update_request import DescriptiveBusinessObjectFormatUpdateRequest
from herdsdk.models.download_business_object_data_storage_file_single_initiation_request import DownloadBusinessObjectDataStorageFileSingleInitiationRequest
from herdsdk.models.download_business_object_data_storage_file_single_initiation_response import DownloadBusinessObjectDataStorageFileSingleInitiationResponse
from herdsdk.models.download_business_object_definition_sample_data_file_single_initiation_request import DownloadBusinessObjectDefinitionSampleDataFileSingleInitiationRequest
from herdsdk.models.download_business_object_definition_sample_data_file_single_initiation_response import DownloadBusinessObjectDefinitionSampleDataFileSingleInitiationResponse
from herdsdk.models.download_single_initiation_response import DownloadSingleInitiationResponse
from herdsdk.models.email_send_request import EmailSendRequest
from herdsdk.models.emr_cluster import EmrCluster
from herdsdk.models.emr_cluster_create_request import EmrClusterCreateRequest
from herdsdk.models.emr_cluster_definition import EmrClusterDefinition
from herdsdk.models.emr_cluster_definition_application import EmrClusterDefinitionApplication
from herdsdk.models.emr_cluster_definition_auto_termination_policy import EmrClusterDefinitionAutoTerminationPolicy
from herdsdk.models.emr_cluster_definition_capacity_reservation_options import EmrClusterDefinitionCapacityReservationOptions
from herdsdk.models.emr_cluster_definition_configuration import EmrClusterDefinitionConfiguration
from herdsdk.models.emr_cluster_definition_create_request import EmrClusterDefinitionCreateRequest
from herdsdk.models.emr_cluster_definition_ebs_block_device_config import EmrClusterDefinitionEbsBlockDeviceConfig
from herdsdk.models.emr_cluster_definition_ebs_configuration import EmrClusterDefinitionEbsConfiguration
from herdsdk.models.emr_cluster_definition_information import EmrClusterDefinitionInformation
from herdsdk.models.emr_cluster_definition_instance_fleet import EmrClusterDefinitionInstanceFleet
from herdsdk.models.emr_cluster_definition_instance_type_config import EmrClusterDefinitionInstanceTypeConfig
from herdsdk.models.emr_cluster_definition_kerberos_attributes import EmrClusterDefinitionKerberosAttributes
from herdsdk.models.emr_cluster_definition_key import EmrClusterDefinitionKey
from herdsdk.models.emr_cluster_definition_keys import EmrClusterDefinitionKeys
from herdsdk.models.emr_cluster_definition_launch_specifications import EmrClusterDefinitionLaunchSpecifications
from herdsdk.models.emr_cluster_definition_on_demand_specification import EmrClusterDefinitionOnDemandSpecification
from herdsdk.models.emr_cluster_definition_spot_specification import EmrClusterDefinitionSpotSpecification
from herdsdk.models.emr_cluster_definition_update_request import EmrClusterDefinitionUpdateRequest
from herdsdk.models.emr_cluster_definition_volume_specification import EmrClusterDefinitionVolumeSpecification
from herdsdk.models.emr_cluster_ebs_block_device import EmrClusterEbsBlockDevice
from herdsdk.models.emr_cluster_instance_fleet import EmrClusterInstanceFleet
from herdsdk.models.emr_cluster_instance_fleet_provisioning_specifications import EmrClusterInstanceFleetProvisioningSpecifications
from herdsdk.models.emr_cluster_instance_fleet_state_change_reason import EmrClusterInstanceFleetStateChangeReason
from herdsdk.models.emr_cluster_instance_fleet_status import EmrClusterInstanceFleetStatus
from herdsdk.models.emr_cluster_instance_fleet_timeline import EmrClusterInstanceFleetTimeline
from herdsdk.models.emr_cluster_instance_type_configuration import EmrClusterInstanceTypeConfiguration
from herdsdk.models.emr_cluster_instance_type_specification import EmrClusterInstanceTypeSpecification
from herdsdk.models.emr_cluster_spot_provisioning_specification import EmrClusterSpotProvisioningSpecification
from herdsdk.models.emr_cluster_volume_specification import EmrClusterVolumeSpecification
from herdsdk.models.emr_hadoop_jar_step import EmrHadoopJarStep
from herdsdk.models.emr_hadoop_jar_step_add_request import EmrHadoopJarStepAddRequest
from herdsdk.models.emr_hive_step import EmrHiveStep
from herdsdk.models.emr_hive_step_add_request import EmrHiveStepAddRequest
from herdsdk.models.emr_master_security_group import EmrMasterSecurityGroup
from herdsdk.models.emr_master_security_group_add_request import EmrMasterSecurityGroupAddRequest
from herdsdk.models.emr_pig_step import EmrPigStep
from herdsdk.models.emr_pig_step_add_request import EmrPigStepAddRequest
from herdsdk.models.emr_shell_step import EmrShellStep
from herdsdk.models.emr_shell_step_add_request import EmrShellStepAddRequest
from herdsdk.models.emr_step import EmrStep
from herdsdk.models.error_information import ErrorInformation
from herdsdk.models.expected_partition_value_information import ExpectedPartitionValueInformation
from herdsdk.models.expected_partition_value_key import ExpectedPartitionValueKey
from herdsdk.models.expected_partition_values_create_request import ExpectedPartitionValuesCreateRequest
from herdsdk.models.expected_partition_values_delete_request import ExpectedPartitionValuesDeleteRequest
from herdsdk.models.expected_partition_values_information import ExpectedPartitionValuesInformation
from herdsdk.models.external_interface import ExternalInterface
from herdsdk.models.external_interface_create_request import ExternalInterfaceCreateRequest
from herdsdk.models.external_interface_key import ExternalInterfaceKey
from herdsdk.models.external_interface_keys import ExternalInterfaceKeys
from herdsdk.models.external_interface_update_request import ExternalInterfaceUpdateRequest
from herdsdk.models.facet import Facet
from herdsdk.models.field import Field
from herdsdk.models.file import File
from herdsdk.models.file_type import FileType
from herdsdk.models.file_type_create_request import FileTypeCreateRequest
from herdsdk.models.file_type_key import FileTypeKey
from herdsdk.models.file_type_keys import FileTypeKeys
from herdsdk.models.global_attribute_definition import GlobalAttributeDefinition
from herdsdk.models.global_attribute_definition_create_request import GlobalAttributeDefinitionCreateRequest
from herdsdk.models.global_attribute_definition_key import GlobalAttributeDefinitionKey
from herdsdk.models.global_attribute_definition_keys import GlobalAttributeDefinitionKeys
from herdsdk.models.hadoop_jar_step import HadoopJarStep
from herdsdk.models.highlight import Highlight
from herdsdk.models.index_search_filter import IndexSearchFilter
from herdsdk.models.index_search_key import IndexSearchKey
from herdsdk.models.index_search_request import IndexSearchRequest
from herdsdk.models.index_search_response import IndexSearchResponse
from herdsdk.models.index_search_result import IndexSearchResult
from herdsdk.models.index_search_result_key import IndexSearchResultKey
from herdsdk.models.index_search_result_type_key import IndexSearchResultTypeKey
from herdsdk.models.instance_definition import InstanceDefinition
from herdsdk.models.instance_definitions import InstanceDefinitions
from herdsdk.models.jdbc_connection import JdbcConnection
from herdsdk.models.jdbc_database_type import JdbcDatabaseType
from herdsdk.models.jdbc_execution_request import JdbcExecutionRequest
from herdsdk.models.jdbc_execution_response import JdbcExecutionResponse
from herdsdk.models.jdbc_statement import JdbcStatement
from herdsdk.models.jdbc_statement_result_set import JdbcStatementResultSet
from herdsdk.models.jdbc_statement_result_set_row import JdbcStatementResultSetRow
from herdsdk.models.jdbc_statement_status import JdbcStatementStatus
from herdsdk.models.jdbc_statement_type import JdbcStatementType
from herdsdk.models.job import Job
from herdsdk.models.job_action import JobAction
from herdsdk.models.job_action_enum import JobActionEnum
from herdsdk.models.job_create_request import JobCreateRequest
from herdsdk.models.job_definition import JobDefinition
from herdsdk.models.job_definition_create_request import JobDefinitionCreateRequest
from herdsdk.models.job_definition_key import JobDefinitionKey
from herdsdk.models.job_definition_keys import JobDefinitionKeys
from herdsdk.models.job_definition_update_request import JobDefinitionUpdateRequest
from herdsdk.models.job_delete_request import JobDeleteRequest
from herdsdk.models.job_signal_request import JobSignalRequest
from herdsdk.models.job_status_enum import JobStatusEnum
from herdsdk.models.job_summaries import JobSummaries
from herdsdk.models.job_summary import JobSummary
from herdsdk.models.job_update_request import JobUpdateRequest
from herdsdk.models.key_value_pair_configuration import KeyValuePairConfiguration
from herdsdk.models.key_value_pair_configurations import KeyValuePairConfigurations
from herdsdk.models.latest_after_partition_value import LatestAfterPartitionValue
from herdsdk.models.latest_before_partition_value import LatestBeforePartitionValue
from herdsdk.models.master_instance_definition import MasterInstanceDefinition
from herdsdk.models.message_header_definition import MessageHeaderDefinition
from herdsdk.models.namespace import Namespace
from herdsdk.models.namespace_authorization import NamespaceAuthorization
from herdsdk.models.namespace_create_request import NamespaceCreateRequest
from herdsdk.models.namespace_iam_role_authorization import NamespaceIamRoleAuthorization
from herdsdk.models.namespace_iam_role_authorization_create_request import NamespaceIamRoleAuthorizationCreateRequest
from herdsdk.models.namespace_iam_role_authorization_key import NamespaceIamRoleAuthorizationKey
from herdsdk.models.namespace_iam_role_authorization_keys import NamespaceIamRoleAuthorizationKeys
from herdsdk.models.namespace_iam_role_authorization_update_request import NamespaceIamRoleAuthorizationUpdateRequest
from herdsdk.models.namespace_key import NamespaceKey
from herdsdk.models.namespace_keys import NamespaceKeys
from herdsdk.models.namespace_permission_enum import NamespacePermissionEnum
from herdsdk.models.namespace_search_filter import NamespaceSearchFilter
from herdsdk.models.namespace_search_key import NamespaceSearchKey
from herdsdk.models.namespace_search_request import NamespaceSearchRequest
from herdsdk.models.namespace_search_response import NamespaceSearchResponse
from herdsdk.models.namespace_update_request import NamespaceUpdateRequest
from herdsdk.models.node_tag import NodeTag
from herdsdk.models.notification_message_definition import NotificationMessageDefinition
from herdsdk.models.notification_message_definitions import NotificationMessageDefinitions
from herdsdk.models.notification_registration_key import NotificationRegistrationKey
from herdsdk.models.notification_registration_status_update_request import NotificationRegistrationStatusUpdateRequest
from herdsdk.models.notification_registration_status_update_response import NotificationRegistrationStatusUpdateResponse
from herdsdk.models.parameter import Parameter
from herdsdk.models.partition import Partition
from herdsdk.models.partition_column import PartitionColumn
from herdsdk.models.partition_key_group import PartitionKeyGroup
from herdsdk.models.partition_key_group_create_request import PartitionKeyGroupCreateRequest
from herdsdk.models.partition_key_group_key import PartitionKeyGroupKey
from herdsdk.models.partition_key_group_keys import PartitionKeyGroupKeys
from herdsdk.models.partition_value_filter import PartitionValueFilter
from herdsdk.models.partition_value_range import PartitionValueRange
from herdsdk.models.registration_date_range_filter import RegistrationDateRangeFilter
from herdsdk.models.relational_table_registration_create_request import RelationalTableRegistrationCreateRequest
from herdsdk.models.relational_table_registration_delete_response import RelationalTableRegistrationDeleteResponse
from herdsdk.models.run_oozie_workflow_request import RunOozieWorkflowRequest
from herdsdk.models.s3_key_prefix_information import S3KeyPrefixInformation
from herdsdk.models.s3_properties_location import S3PropertiesLocation
from herdsdk.models.sample_data_file import SampleDataFile
from herdsdk.models.schema import Schema
from herdsdk.models.schema_column import SchemaColumn
from herdsdk.models.script_definition import ScriptDefinition
from herdsdk.models.search_index import SearchIndex
from herdsdk.models.search_index_activation import SearchIndexActivation
from herdsdk.models.search_index_activation_create_request import SearchIndexActivationCreateRequest
from herdsdk.models.search_index_create_request import SearchIndexCreateRequest
from herdsdk.models.search_index_key import SearchIndexKey
from herdsdk.models.search_index_keys import SearchIndexKeys
from herdsdk.models.search_index_statistics import SearchIndexStatistics
from herdsdk.models.security_function import SecurityFunction
from herdsdk.models.security_function_create_request import SecurityFunctionCreateRequest
from herdsdk.models.security_function_key import SecurityFunctionKey
from herdsdk.models.security_function_keys import SecurityFunctionKeys
from herdsdk.models.security_role import SecurityRole
from herdsdk.models.security_role_create_request import SecurityRoleCreateRequest
from herdsdk.models.security_role_function import SecurityRoleFunction
from herdsdk.models.security_role_function_create_request import SecurityRoleFunctionCreateRequest
from herdsdk.models.security_role_function_key import SecurityRoleFunctionKey
from herdsdk.models.security_role_function_keys import SecurityRoleFunctionKeys
from herdsdk.models.security_role_key import SecurityRoleKey
from herdsdk.models.security_role_keys import SecurityRoleKeys
from herdsdk.models.security_role_update_request import SecurityRoleUpdateRequest
from herdsdk.models.status_change_reason import StatusChangeReason
from herdsdk.models.status_timeline import StatusTimeline
from herdsdk.models.storage import Storage
from herdsdk.models.storage_attributes_update_request import StorageAttributesUpdateRequest
from herdsdk.models.storage_business_object_definition_daily_upload_stat import StorageBusinessObjectDefinitionDailyUploadStat
from herdsdk.models.storage_business_object_definition_daily_upload_stats import StorageBusinessObjectDefinitionDailyUploadStats
from herdsdk.models.storage_create_request import StorageCreateRequest
from herdsdk.models.storage_daily_upload_stat import StorageDailyUploadStat
from herdsdk.models.storage_daily_upload_stats import StorageDailyUploadStats
from herdsdk.models.storage_directory import StorageDirectory
from herdsdk.models.storage_file import StorageFile
from herdsdk.models.storage_key import StorageKey
from herdsdk.models.storage_keys import StorageKeys
from herdsdk.models.storage_platform import StoragePlatform
from herdsdk.models.storage_platforms import StoragePlatforms
from herdsdk.models.storage_policy import StoragePolicy
from herdsdk.models.storage_policy_create_request import StoragePolicyCreateRequest
from herdsdk.models.storage_policy_filter import StoragePolicyFilter
from herdsdk.models.storage_policy_key import StoragePolicyKey
from herdsdk.models.storage_policy_keys import StoragePolicyKeys
from herdsdk.models.storage_policy_rule import StoragePolicyRule
from herdsdk.models.storage_policy_transition import StoragePolicyTransition
from herdsdk.models.storage_policy_update_request import StoragePolicyUpdateRequest
from herdsdk.models.storage_unit import StorageUnit
from herdsdk.models.storage_unit_create_request import StorageUnitCreateRequest
from herdsdk.models.storage_unit_download_credential import StorageUnitDownloadCredential
from herdsdk.models.storage_unit_notification_filter import StorageUnitNotificationFilter
from herdsdk.models.storage_unit_notification_registration import StorageUnitNotificationRegistration
from herdsdk.models.storage_unit_notification_registration_create_request import StorageUnitNotificationRegistrationCreateRequest
from herdsdk.models.storage_unit_notification_registration_keys import StorageUnitNotificationRegistrationKeys
from herdsdk.models.storage_unit_notification_registration_update_request import StorageUnitNotificationRegistrationUpdateRequest
from herdsdk.models.storage_unit_status_change_event import StorageUnitStatusChangeEvent
from herdsdk.models.storage_unit_upload_credential import StorageUnitUploadCredential
from herdsdk.models.storage_update_request import StorageUpdateRequest
from herdsdk.models.subject_matter_expert import SubjectMatterExpert
from herdsdk.models.subject_matter_expert_contact_details import SubjectMatterExpertContactDetails
from herdsdk.models.subject_matter_expert_key import SubjectMatterExpertKey
from herdsdk.models.system_job_run_request import SystemJobRunRequest
from herdsdk.models.system_job_run_response import SystemJobRunResponse
from herdsdk.models.tag import Tag
from herdsdk.models.tag_child import TagChild
from herdsdk.models.tag_create_request import TagCreateRequest
from herdsdk.models.tag_key import TagKey
from herdsdk.models.tag_list_response import TagListResponse
from herdsdk.models.tag_search_filter import TagSearchFilter
from herdsdk.models.tag_search_key import TagSearchKey
from herdsdk.models.tag_search_request import TagSearchRequest
from herdsdk.models.tag_search_response import TagSearchResponse
from herdsdk.models.tag_type import TagType
from herdsdk.models.tag_type_create_request import TagTypeCreateRequest
from herdsdk.models.tag_type_key import TagTypeKey
from herdsdk.models.tag_type_keys import TagTypeKeys
from herdsdk.models.tag_type_search_request import TagTypeSearchRequest
from herdsdk.models.tag_type_search_response import TagTypeSearchResponse
from herdsdk.models.tag_type_update_request import TagTypeUpdateRequest
from herdsdk.models.tag_update_request import TagUpdateRequest
from herdsdk.models.timeout_validation_response import TimeoutValidationResponse
from herdsdk.models.upload_business_object_definition_sample_data_file_initiation_request import UploadBusinessObjectDefinitionSampleDataFileInitiationRequest
from herdsdk.models.upload_business_object_definition_sample_data_file_initiation_response import UploadBusinessObjectDefinitionSampleDataFileInitiationResponse
from herdsdk.models.upload_single_credential_extension_response import UploadSingleCredentialExtensionResponse
from herdsdk.models.upload_single_initiation_request import UploadSingleInitiationRequest
from herdsdk.models.upload_single_initiation_response import UploadSingleInitiationResponse
from herdsdk.models.user_authorizations import UserAuthorizations
from herdsdk.models.user_namespace_authorization import UserNamespaceAuthorization
from herdsdk.models.user_namespace_authorization_create_request import UserNamespaceAuthorizationCreateRequest
from herdsdk.models.user_namespace_authorization_key import UserNamespaceAuthorizationKey
from herdsdk.models.user_namespace_authorization_update_request import UserNamespaceAuthorizationUpdateRequest
from herdsdk.models.user_namespace_authorizations import UserNamespaceAuthorizations
from herdsdk.models.workflow_error import WorkflowError
from herdsdk.models.workflow_step import WorkflowStep



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EmrClusterEbsBlockDevice(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'volume_specification': 'EmrClusterVolumeSpecification',
        'device': 'str',
        'volumes_per_instance': 'int'
    }

    attribute_map = {
        'volume_specification': 'volumeSpecification',
        'device': 'device',
        'volumes_per_instance': 'volumesPerInstance'
    }

    def __init__(self, volume_specification=None, device=None, volumes_per_instance=None):  # noqa: E501
        """EmrClusterEbsBlockDevice - a model defined in OpenAPI"""  # noqa: E501

        self._volume_specification = None
        self._device = None
        self._volumes_per_instance = None
        self.discriminator = None

        if volume_specification is not None:
            self.volume_specification = volume_specification
        if device is not None:
            self.device = device
        if volumes_per_instance is not None:
            self.volumes_per_instance = volumes_per_instance

    @property
    def volume_specification(self):
        """Gets the volume_specification of this EmrClusterEbsBlockDevice.  # noqa: E501


        :return: The volume_specification of this EmrClusterEbsBlockDevice.  # noqa: E501
        :rtype: EmrClusterVolumeSpecification
        """
        return self._volume_specification

    @volume_specification.setter
    def volume_specification(self, volume_specification):
        """Sets the volume_specification of this EmrClusterEbsBlockDevice.


        :param volume_specification: The volume_specification of this EmrClusterEbsBlockDevice.  # noqa: E501
        :type: EmrClusterVolumeSpecification
        """

        self._volume_specification = volume_specification

    @property
    def device(self):
        """Gets the device of this EmrClusterEbsBlockDevice.  # noqa: E501

        The device name that is exposed to the instance, such as /dev/sdh.                  # noqa: E501

        :return: The device of this EmrClusterEbsBlockDevice.  # noqa: E501
        :rtype: str
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this EmrClusterEbsBlockDevice.

        The device name that is exposed to the instance, such as /dev/sdh.                  # noqa: E501

        :param device: The device of this EmrClusterEbsBlockDevice.  # noqa: E501
        :type: str
        """

        self._device = device

    @property
    def volumes_per_instance(self):
        """Gets the volumes_per_instance of this EmrClusterEbsBlockDevice.  # noqa: E501

        Number of EBS volumes with a specific volume configuration that will be associated with every instance in the instance group                  # noqa: E501

        :return: The volumes_per_instance of this EmrClusterEbsBlockDevice.  # noqa: E501
        :rtype: int
        """
        return self._volumes_per_instance

    @volumes_per_instance.setter
    def volumes_per_instance(self, volumes_per_instance):
        """Sets the volumes_per_instance of this EmrClusterEbsBlockDevice.

        Number of EBS volumes with a specific volume configuration that will be associated with every instance in the instance group                  # noqa: E501

        :param volumes_per_instance: The volumes_per_instance of this EmrClusterEbsBlockDevice.  # noqa: E501
        :type: int
        """

        self._volumes_per_instance = volumes_per_instance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmrClusterEbsBlockDevice):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EmailSendRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'to': 'str',
        'cc': 'str',
        'bcc': 'str',
        'subject': 'str',
        'text': 'str',
        'reply_to': 'str',
        'source': 'str'
    }

    attribute_map = {
        'to': 'to',
        'cc': 'cc',
        'bcc': 'bcc',
        'subject': 'subject',
        'text': 'text',
        'reply_to': 'replyTo',
        'source': 'source'
    }

    def __init__(self, to=None, cc=None, bcc=None, subject=None, text=None, reply_to=None, source=None):  # noqa: E501
        """EmailSendRequest - a model defined in OpenAPI"""  # noqa: E501

        self._to = None
        self._cc = None
        self._bcc = None
        self._subject = None
        self._text = None
        self._reply_to = None
        self._source = None
        self.discriminator = None

        if to is not None:
            self.to = to
        if cc is not None:
            self.cc = cc
        if bcc is not None:
            self.bcc = bcc
        self.subject = subject
        if text is not None:
            self.text = text
        if reply_to is not None:
            self.reply_to = reply_to
        if source is not None:
            self.source = source

    @property
    def to(self):
        """Gets the to of this EmailSendRequest.  # noqa: E501


        :return: The to of this EmailSendRequest.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this EmailSendRequest.


        :param to: The to of this EmailSendRequest.  # noqa: E501
        :type: str
        """

        self._to = to

    @property
    def cc(self):
        """Gets the cc of this EmailSendRequest.  # noqa: E501


        :return: The cc of this EmailSendRequest.  # noqa: E501
        :rtype: str
        """
        return self._cc

    @cc.setter
    def cc(self, cc):
        """Sets the cc of this EmailSendRequest.


        :param cc: The cc of this EmailSendRequest.  # noqa: E501
        :type: str
        """

        self._cc = cc

    @property
    def bcc(self):
        """Gets the bcc of this EmailSendRequest.  # noqa: E501


        :return: The bcc of this EmailSendRequest.  # noqa: E501
        :rtype: str
        """
        return self._bcc

    @bcc.setter
    def bcc(self, bcc):
        """Sets the bcc of this EmailSendRequest.


        :param bcc: The bcc of this EmailSendRequest.  # noqa: E501
        :type: str
        """

        self._bcc = bcc

    @property
    def subject(self):
        """Gets the subject of this EmailSendRequest.  # noqa: E501


        :return: The subject of this EmailSendRequest.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this EmailSendRequest.


        :param subject: The subject of this EmailSendRequest.  # noqa: E501
        :type: str
        """
        if subject is None:
            raise ValueError("Invalid value for `subject`, must not be `None`")  # noqa: E501

        self._subject = subject

    @property
    def text(self):
        """Gets the text of this EmailSendRequest.  # noqa: E501


        :return: The text of this EmailSendRequest.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this EmailSendRequest.


        :param text: The text of this EmailSendRequest.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def reply_to(self):
        """Gets the reply_to of this EmailSendRequest.  # noqa: E501


        :return: The reply_to of this EmailSendRequest.  # noqa: E501
        :rtype: str
        """
        return self._reply_to

    @reply_to.setter
    def reply_to(self, reply_to):
        """Sets the reply_to of this EmailSendRequest.


        :param reply_to: The reply_to of this EmailSendRequest.  # noqa: E501
        :type: str
        """

        self._reply_to = reply_to

    @property
    def source(self):
        """Gets the source of this EmailSendRequest.  # noqa: E501


        :return: The source of this EmailSendRequest.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this EmailSendRequest.


        :param source: The source of this EmailSendRequest.  # noqa: E501
        :type: str
        """

        self._source = source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailSendRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.partition_key_group_api import PartitionKeyGroupApi  # noqa: E501
from herdsdk.rest import ApiException


class TestPartitionKeyGroupApi(unittest.TestCase):
    """PartitionKeyGroupApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.partition_key_group_api.PartitionKeyGroupApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_partition_key_group_create_partition_key_group(self):
        """Test case for partition_key_group_create_partition_key_group

        createPartitionKeyGroup  # noqa: E501
        """
        pass

    def test_partition_key_group_delete_partition_key_group(self):
        """Test case for partition_key_group_delete_partition_key_group

        deletePartitionKeyGroup  # noqa: E501
        """
        pass

    def test_partition_key_group_get_partition_key_group(self):
        """Test case for partition_key_group_get_partition_key_group

        getPartitionKeyGroup  # noqa: E501
        """
        pass

    def test_partition_key_group_get_partition_key_groups(self):
        """Test case for partition_key_group_get_partition_key_groups

        getPartitionKeyGroups  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class RegistrationDateRangeFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'start_registration_date': 'datetime',
        'end_registration_date': 'datetime'
    }

    attribute_map = {
        'start_registration_date': 'startRegistrationDate',
        'end_registration_date': 'endRegistrationDate'
    }

    def __init__(self, start_registration_date=None, end_registration_date=None):  # noqa: E501
        """RegistrationDateRangeFilter - a model defined in OpenAPI"""  # noqa: E501

        self._start_registration_date = None
        self._end_registration_date = None
        self.discriminator = None

        if start_registration_date is not None:
            self.start_registration_date = start_registration_date
        if end_registration_date is not None:
            self.end_registration_date = end_registration_date

    @property
    def start_registration_date(self):
        """Gets the start_registration_date of this RegistrationDateRangeFilter.  # noqa: E501

                           Business object data registration start datetime. The following formats are supported:                   \"yyyy-MM-dd\" eg. 2018-01-21                   \"yyyy-MM-dd'T'HH:mm\" eg. 2015-12-25T00:01                   \"yyyy-MM-dd'T'HH:mmZ\" eg. 2015-12-25T00:01+04:00                   \"yyyy-MM-dd'T'HH:mm:ss\" eg. 2018-02-03T10:00:02                   \"yyyy-MM-dd'T'HH:mm:ssZ\" eg. 2018-02-03T10:00:02+04:00                   \"yyyy-MM-dd HH:mm:ss\" eg. 2018-02-03 10:00:02                   \"yyyy-MM-dd HH:mm:ssZ\" eg. 2018-03-03 10:00:02+05:30                  # noqa: E501

        :return: The start_registration_date of this RegistrationDateRangeFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._start_registration_date

    @start_registration_date.setter
    def start_registration_date(self, start_registration_date):
        """Sets the start_registration_date of this RegistrationDateRangeFilter.

                           Business object data registration start datetime. The following formats are supported:                   \"yyyy-MM-dd\" eg. 2018-01-21                   \"yyyy-MM-dd'T'HH:mm\" eg. 2015-12-25T00:01                   \"yyyy-MM-dd'T'HH:mmZ\" eg. 2015-12-25T00:01+04:00                   \"yyyy-MM-dd'T'HH:mm:ss\" eg. 2018-02-03T10:00:02                   \"yyyy-MM-dd'T'HH:mm:ssZ\" eg. 2018-02-03T10:00:02+04:00                   \"yyyy-MM-dd HH:mm:ss\" eg. 2018-02-03 10:00:02                   \"yyyy-MM-dd HH:mm:ssZ\" eg. 2018-03-03 10:00:02+05:30                  # noqa: E501

        :param start_registration_date: The start_registration_date of this RegistrationDateRangeFilter.  # noqa: E501
        :type: datetime
        """

        self._start_registration_date = start_registration_date

    @property
    def end_registration_date(self):
        """Gets the end_registration_date of this RegistrationDateRangeFilter.  # noqa: E501

                           Business object data registration end datetime. The following formats are supported:                   \"yyyy-MM-dd\" eg. 2018-01-21                   \"yyyy-MM-dd'T'HH:mm\" eg. 2015-12-25T00:01                   \"yyyy-MM-dd'T'HH:mmZ\" eg. 2015-12-25T00:01+04:00                   \"yyyy-MM-dd'T'HH:mm:ss\" eg. 2018-02-03T10:00:02                   \"yyyy-MM-dd'T'HH:mm:ssZ\" eg. 2018-02-03T10:00:02+04:00                   \"yyyy-MM-dd HH:mm:ss\" eg. 2018-02-03 10:00:02                   \"yyyy-MM-dd HH:mm:ssZ\" eg. 2018-03-03 10:00:02+05:30                  # noqa: E501

        :return: The end_registration_date of this RegistrationDateRangeFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._end_registration_date

    @end_registration_date.setter
    def end_registration_date(self, end_registration_date):
        """Sets the end_registration_date of this RegistrationDateRangeFilter.

                           Business object data registration end datetime. The following formats are supported:                   \"yyyy-MM-dd\" eg. 2018-01-21                   \"yyyy-MM-dd'T'HH:mm\" eg. 2015-12-25T00:01                   \"yyyy-MM-dd'T'HH:mmZ\" eg. 2015-12-25T00:01+04:00                   \"yyyy-MM-dd'T'HH:mm:ss\" eg. 2018-02-03T10:00:02                   \"yyyy-MM-dd'T'HH:mm:ssZ\" eg. 2018-02-03T10:00:02+04:00                   \"yyyy-MM-dd HH:mm:ss\" eg. 2018-02-03 10:00:02                   \"yyyy-MM-dd HH:mm:ssZ\" eg. 2018-03-03 10:00:02+05:30                  # noqa: E501

        :param end_registration_date: The end_registration_date of this RegistrationDateRangeFilter.  # noqa: E501
        :type: datetime
        """

        self._end_registration_date = end_registration_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegistrationDateRangeFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.models.business_object_data_retry_storage_policy_transition_request import BusinessObjectDataRetryStoragePolicyTransitionRequest  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectDataRetryStoragePolicyTransitionRequest(unittest.TestCase):
    """BusinessObjectDataRetryStoragePolicyTransitionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBusinessObjectDataRetryStoragePolicyTransitionRequest(self):
        """Test BusinessObjectDataRetryStoragePolicyTransitionRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = herdsdk.models.business_object_data_retry_storage_policy_transition_request.BusinessObjectDataRetryStoragePolicyTransitionRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.upload_and_download_api import UploadAndDownloadApi  # noqa: E501
from herdsdk.rest import ApiException


class TestUploadAndDownloadApi(unittest.TestCase):
    """UploadAndDownloadApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.upload_and_download_api.UploadAndDownloadApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_uploadand_download_extend_upload_single_credentials(self):
        """Test case for uploadand_download_extend_upload_single_credentials

        extendUploadSingleCredentials  # noqa: E501
        """
        pass

    def test_uploadand_download_initiate_download_single(self):
        """Test case for uploadand_download_initiate_download_single

        initiateDownloadSingle  # noqa: E501
        """
        pass

    def test_uploadand_download_initiate_download_single_business_object_data_storage_file(self):
        """Test case for uploadand_download_initiate_download_single_business_object_data_storage_file

        initiateDownloadSingleBusinessObjectDataStorageFile  # noqa: E501
        """
        pass

    def test_uploadand_download_initiate_download_single_sample_file(self):
        """Test case for uploadand_download_initiate_download_single_sample_file

        initiateDownloadSingleSampleFile  # noqa: E501
        """
        pass

    def test_uploadand_download_initiate_upload_sample_file(self):
        """Test case for uploadand_download_initiate_upload_sample_file

        initiateUploadSampleFile  # noqa: E501
        """
        pass

    def test_uploadand_download_initiate_upload_single(self):
        """Test case for uploadand_download_initiate_upload_single

        initiateUploadSingle  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EmrClusterDefinitionVolumeSpecification(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'volume_type': 'str',
        'iops': 'int',
        'size_in_gb': 'int',
        'throughput': 'int'
    }

    attribute_map = {
        'volume_type': 'volumeType',
        'iops': 'iops',
        'size_in_gb': 'sizeInGB',
        'throughput': 'throughput'
    }

    def __init__(self, volume_type=None, iops=None, size_in_gb=None, throughput=None):  # noqa: E501
        """EmrClusterDefinitionVolumeSpecification - a model defined in OpenAPI"""  # noqa: E501

        self._volume_type = None
        self._iops = None
        self._size_in_gb = None
        self._throughput = None
        self.discriminator = None

        if volume_type is not None:
            self.volume_type = volume_type
        if iops is not None:
            self.iops = iops
        if size_in_gb is not None:
            self.size_in_gb = size_in_gb
        if throughput is not None:
            self.throughput = throughput

    @property
    def volume_type(self):
        """Gets the volume_type of this EmrClusterDefinitionVolumeSpecification.  # noqa: E501

        The volume type. Volume types supported are gp2, io1, standard  # noqa: E501

        :return: The volume_type of this EmrClusterDefinitionVolumeSpecification.  # noqa: E501
        :rtype: str
        """
        return self._volume_type

    @volume_type.setter
    def volume_type(self, volume_type):
        """Sets the volume_type of this EmrClusterDefinitionVolumeSpecification.

        The volume type. Volume types supported are gp2, io1, standard  # noqa: E501

        :param volume_type: The volume_type of this EmrClusterDefinitionVolumeSpecification.  # noqa: E501
        :type: str
        """

        self._volume_type = volume_type

    @property
    def iops(self):
        """Gets the iops of this EmrClusterDefinitionVolumeSpecification.  # noqa: E501

        The number of I/O operations per second (IOPS) that the volume supports  # noqa: E501

        :return: The iops of this EmrClusterDefinitionVolumeSpecification.  # noqa: E501
        :rtype: int
        """
        return self._iops

    @iops.setter
    def iops(self, iops):
        """Sets the iops of this EmrClusterDefinitionVolumeSpecification.

        The number of I/O operations per second (IOPS) that the volume supports  # noqa: E501

        :param iops: The iops of this EmrClusterDefinitionVolumeSpecification.  # noqa: E501
        :type: int
        """

        self._iops = iops

    @property
    def size_in_gb(self):
        """Gets the size_in_gb of this EmrClusterDefinitionVolumeSpecification.  # noqa: E501

        The volume size, in gibibytes (GiB). This can be a number from 1 - 1024. If the volume type is EBS-optimized, the minimum value                   is 10                  # noqa: E501

        :return: The size_in_gb of this EmrClusterDefinitionVolumeSpecification.  # noqa: E501
        :rtype: int
        """
        return self._size_in_gb

    @size_in_gb.setter
    def size_in_gb(self, size_in_gb):
        """Sets the size_in_gb of this EmrClusterDefinitionVolumeSpecification.

        The volume size, in gibibytes (GiB). This can be a number from 1 - 1024. If the volume type is EBS-optimized, the minimum value                   is 10                  # noqa: E501

        :param size_in_gb: The size_in_gb of this EmrClusterDefinitionVolumeSpecification.  # noqa: E501
        :type: int
        """

        self._size_in_gb = size_in_gb

    @property
    def throughput(self):
        """Gets the throughput of this EmrClusterDefinitionVolumeSpecification.  # noqa: E501

        The throughput, in mebibyte per second (MiB/s). This optional parameter can be a number from 125 - 1000 and is valid only for                   gp3 volumes                  # noqa: E501

        :return: The throughput of this EmrClusterDefinitionVolumeSpecification.  # noqa: E501
        :rtype: int
        """
        return self._throughput

    @throughput.setter
    def throughput(self, throughput):
        """Sets the throughput of this EmrClusterDefinitionVolumeSpecification.

        The throughput, in mebibyte per second (MiB/s). This optional parameter can be a number from 125 - 1000 and is valid only for                   gp3 volumes                  # noqa: E501

        :param throughput: The throughput of this EmrClusterDefinitionVolumeSpecification.  # noqa: E501
        :type: int
        """

        self._throughput = throughput

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmrClusterDefinitionVolumeSpecification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectDataAvailabilityRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'business_object_format_usage': 'str',
        'business_object_format_file_type': 'str',
        'business_object_format_version': 'int',
        'partition_value_filters': 'list[PartitionValueFilter]',
        'partition_value_filter': 'PartitionValueFilter',
        'business_object_data_version': 'int',
        'business_object_data_status': 'str',
        'storage_names': 'list[str]',
        'storage_name': 'str',
        'include_all_registered_sub_partitions': 'bool'
    }

    attribute_map = {
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'business_object_format_usage': 'businessObjectFormatUsage',
        'business_object_format_file_type': 'businessObjectFormatFileType',
        'business_object_format_version': 'businessObjectFormatVersion',
        'partition_value_filters': 'partitionValueFilters',
        'partition_value_filter': 'partitionValueFilter',
        'business_object_data_version': 'businessObjectDataVersion',
        'business_object_data_status': 'businessObjectDataStatus',
        'storage_names': 'storageNames',
        'storage_name': 'storageName',
        'include_all_registered_sub_partitions': 'includeAllRegisteredSubPartitions'
    }

    def __init__(self, namespace=None, business_object_definition_name=None, business_object_format_usage=None, business_object_format_file_type=None, business_object_format_version=None, partition_value_filters=None, partition_value_filter=None, business_object_data_version=None, business_object_data_status=None, storage_names=None, storage_name=None, include_all_registered_sub_partitions=None):  # noqa: E501
        """BusinessObjectDataAvailabilityRequest - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._business_object_definition_name = None
        self._business_object_format_usage = None
        self._business_object_format_file_type = None
        self._business_object_format_version = None
        self._partition_value_filters = None
        self._partition_value_filter = None
        self._business_object_data_version = None
        self._business_object_data_status = None
        self._storage_names = None
        self._storage_name = None
        self._include_all_registered_sub_partitions = None
        self.discriminator = None

        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        self.business_object_format_usage = business_object_format_usage
        self.business_object_format_file_type = business_object_format_file_type
        if business_object_format_version is not None:
            self.business_object_format_version = business_object_format_version
        if partition_value_filters is not None:
            self.partition_value_filters = partition_value_filters
        if partition_value_filter is not None:
            self.partition_value_filter = partition_value_filter
        if business_object_data_version is not None:
            self.business_object_data_version = business_object_data_version
        if business_object_data_status is not None:
            self.business_object_data_status = business_object_data_status
        if storage_names is not None:
            self.storage_names = storage_names
        if storage_name is not None:
            self.storage_name = storage_name
        if include_all_registered_sub_partitions is not None:
            self.include_all_registered_sub_partitions = include_all_registered_sub_partitions

    @property
    def namespace(self):
        """Gets the namespace of this BusinessObjectDataAvailabilityRequest.  # noqa: E501

        The Namespace to which a Business Object Format is related  # noqa: E501

        :return: The namespace of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BusinessObjectDataAvailabilityRequest.

        The Namespace to which a Business Object Format is related  # noqa: E501

        :param namespace: The namespace of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this BusinessObjectDataAvailabilityRequest.  # noqa: E501

        The name of the Business Object Definition to which a Business Object Format is related  # noqa: E501

        :return: The business_object_definition_name of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this BusinessObjectDataAvailabilityRequest.

        The name of the Business Object Definition to which a Business Object Format is related  # noqa: E501

        :param business_object_definition_name: The business_object_definition_name of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def business_object_format_usage(self):
        """Gets the business_object_format_usage of this BusinessObjectDataAvailabilityRequest.  # noqa: E501

        The Usage of a Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format. Does not have to be unique in the system, the Usage string is frequently shared across formats for multiple Business Object                   Definitions                  # noqa: E501

        :return: The business_object_format_usage of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_usage

    @business_object_format_usage.setter
    def business_object_format_usage(self, business_object_format_usage):
        """Sets the business_object_format_usage of this BusinessObjectDataAvailabilityRequest.

        The Usage of a Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format. Does not have to be unique in the system, the Usage string is frequently shared across formats for multiple Business Object                   Definitions                  # noqa: E501

        :param business_object_format_usage: The business_object_format_usage of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :type: str
        """
        if business_object_format_usage is None:
            raise ValueError("Invalid value for `business_object_format_usage`, must not be `None`")  # noqa: E501

        self._business_object_format_usage = business_object_format_usage

    @property
    def business_object_format_file_type(self):
        """Gets the business_object_format_file_type of this BusinessObjectDataAvailabilityRequest.  # noqa: E501

        A File Type known to the system that describes the file type of data stored under a Business Object Format  # noqa: E501

        :return: The business_object_format_file_type of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_file_type

    @business_object_format_file_type.setter
    def business_object_format_file_type(self, business_object_format_file_type):
        """Sets the business_object_format_file_type of this BusinessObjectDataAvailabilityRequest.

        A File Type known to the system that describes the file type of data stored under a Business Object Format  # noqa: E501

        :param business_object_format_file_type: The business_object_format_file_type of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :type: str
        """
        if business_object_format_file_type is None:
            raise ValueError("Invalid value for `business_object_format_file_type`, must not be `None`")  # noqa: E501

        self._business_object_format_file_type = business_object_format_file_type

    @property
    def business_object_format_version(self):
        """Gets the business_object_format_version of this BusinessObjectDataAvailabilityRequest.  # noqa: E501

        The Business Object Format Version for a previously registered Business Object Format  # noqa: E501

        :return: The business_object_format_version of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :rtype: int
        """
        return self._business_object_format_version

    @business_object_format_version.setter
    def business_object_format_version(self, business_object_format_version):
        """Sets the business_object_format_version of this BusinessObjectDataAvailabilityRequest.

        The Business Object Format Version for a previously registered Business Object Format  # noqa: E501

        :param business_object_format_version: The business_object_format_version of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :type: int
        """

        self._business_object_format_version = business_object_format_version

    @property
    def partition_value_filters(self):
        """Gets the partition_value_filters of this BusinessObjectDataAvailabilityRequest.  # noqa: E501

        A container for Partition Value Filters  # noqa: E501

        :return: The partition_value_filters of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :rtype: list[PartitionValueFilter]
        """
        return self._partition_value_filters

    @partition_value_filters.setter
    def partition_value_filters(self, partition_value_filters):
        """Sets the partition_value_filters of this BusinessObjectDataAvailabilityRequest.

        A container for Partition Value Filters  # noqa: E501

        :param partition_value_filters: The partition_value_filters of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :type: list[PartitionValueFilter]
        """

        self._partition_value_filters = partition_value_filters

    @property
    def partition_value_filter(self):
        """Gets the partition_value_filter of this BusinessObjectDataAvailabilityRequest.  # noqa: E501


        :return: The partition_value_filter of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :rtype: PartitionValueFilter
        """
        return self._partition_value_filter

    @partition_value_filter.setter
    def partition_value_filter(self, partition_value_filter):
        """Sets the partition_value_filter of this BusinessObjectDataAvailabilityRequest.


        :param partition_value_filter: The partition_value_filter of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :type: PartitionValueFilter
        """

        self._partition_value_filter = partition_value_filter

    @property
    def business_object_data_version(self):
        """Gets the business_object_data_version of this BusinessObjectDataAvailabilityRequest.  # noqa: E501

        The numeric version of a Business Object Data  # noqa: E501

        :return: The business_object_data_version of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :rtype: int
        """
        return self._business_object_data_version

    @business_object_data_version.setter
    def business_object_data_version(self, business_object_data_version):
        """Sets the business_object_data_version of this BusinessObjectDataAvailabilityRequest.

        The numeric version of a Business Object Data  # noqa: E501

        :param business_object_data_version: The business_object_data_version of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :type: int
        """

        self._business_object_data_version = business_object_data_version

    @property
    def business_object_data_status(self):
        """Gets the business_object_data_status of this BusinessObjectDataAvailabilityRequest.  # noqa: E501

        An optional Business Object Data Status value for available Business Object Data. Accepted values are VALID and all                   pre-registration status values, such as PROCESSING, UPLOADING, and PENDING_VALID. Default value is VALID. The request cannot                   contain both businessObjectDataVersion and businessObjectDataStatus values                  # noqa: E501

        :return: The business_object_data_status of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_data_status

    @business_object_data_status.setter
    def business_object_data_status(self, business_object_data_status):
        """Sets the business_object_data_status of this BusinessObjectDataAvailabilityRequest.

        An optional Business Object Data Status value for available Business Object Data. Accepted values are VALID and all                   pre-registration status values, such as PROCESSING, UPLOADING, and PENDING_VALID. Default value is VALID. The request cannot                   contain both businessObjectDataVersion and businessObjectDataStatus values                  # noqa: E501

        :param business_object_data_status: The business_object_data_status of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :type: str
        """

        self._business_object_data_status = business_object_data_status

    @property
    def storage_names(self):
        """Gets the storage_names of this BusinessObjectDataAvailabilityRequest.  # noqa: E501

        A container for Storage Names to include when checking for Business Object Data availability  # noqa: E501

        :return: The storage_names of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._storage_names

    @storage_names.setter
    def storage_names(self, storage_names):
        """Sets the storage_names of this BusinessObjectDataAvailabilityRequest.

        A container for Storage Names to include when checking for Business Object Data availability  # noqa: E501

        :param storage_names: The storage_names of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :type: list[str]
        """

        self._storage_names = storage_names

    @property
    def storage_name(self):
        """Gets the storage_name of this BusinessObjectDataAvailabilityRequest.  # noqa: E501

        Name of an existing storage known to the System. Required when StorageName is present  # noqa: E501

        :return: The storage_name of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :rtype: str
        """
        return self._storage_name

    @storage_name.setter
    def storage_name(self, storage_name):
        """Sets the storage_name of this BusinessObjectDataAvailabilityRequest.

        Name of an existing storage known to the System. Required when StorageName is present  # noqa: E501

        :param storage_name: The storage_name of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :type: str
        """

        self._storage_name = storage_name

    @property
    def include_all_registered_sub_partitions(self):
        """Gets the include_all_registered_sub_partitions of this BusinessObjectDataAvailabilityRequest.  # noqa: E501

        Specifies to perform an exhaustive search to return availability for ALL registered sub-partitions (registered as individual                   business object data instances) except for the ones with \"DELETED\" status. This parameter has no impact when business object data version is                   specified. Default value is false, which means that availability ignores any \"not available\" registered sub-partitions when it finds at least                   one \"VALID\" registered sub-partitions for a requested business object data partition value                  # noqa: E501

        :return: The include_all_registered_sub_partitions of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_all_registered_sub_partitions

    @include_all_registered_sub_partitions.setter
    def include_all_registered_sub_partitions(self, include_all_registered_sub_partitions):
        """Sets the include_all_registered_sub_partitions of this BusinessObjectDataAvailabilityRequest.

        Specifies to perform an exhaustive search to return availability for ALL registered sub-partitions (registered as individual                   business object data instances) except for the ones with \"DELETED\" status. This parameter has no impact when business object data version is                   specified. Default value is false, which means that availability ignores any \"not available\" registered sub-partitions when it finds at least                   one \"VALID\" registered sub-partitions for a requested business object data partition value                  # noqa: E501

        :param include_all_registered_sub_partitions: The include_all_registered_sub_partitions of this BusinessObjectDataAvailabilityRequest.  # noqa: E501
        :type: bool
        """

        self._include_all_registered_sub_partitions = include_all_registered_sub_partitions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectDataAvailabilityRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EmrClusterDefinitionSpotSpecification(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'timeout_duration_minutes': 'int',
        'timeout_action': 'str',
        'block_duration_minutes': 'int',
        'allocation_strategy': 'str'
    }

    attribute_map = {
        'timeout_duration_minutes': 'timeoutDurationMinutes',
        'timeout_action': 'timeoutAction',
        'block_duration_minutes': 'blockDurationMinutes',
        'allocation_strategy': 'allocationStrategy'
    }

    def __init__(self, timeout_duration_minutes=None, timeout_action=None, block_duration_minutes=None, allocation_strategy=None):  # noqa: E501
        """EmrClusterDefinitionSpotSpecification - a model defined in OpenAPI"""  # noqa: E501

        self._timeout_duration_minutes = None
        self._timeout_action = None
        self._block_duration_minutes = None
        self._allocation_strategy = None
        self.discriminator = None

        if timeout_duration_minutes is not None:
            self.timeout_duration_minutes = timeout_duration_minutes
        if timeout_action is not None:
            self.timeout_action = timeout_action
        if block_duration_minutes is not None:
            self.block_duration_minutes = block_duration_minutes
        if allocation_strategy is not None:
            self.allocation_strategy = allocation_strategy

    @property
    def timeout_duration_minutes(self):
        """Gets the timeout_duration_minutes of this EmrClusterDefinitionSpotSpecification.  # noqa: E501

        The spot provisioning timeout period in minutes. If Spot instances are not provisioned within this time period, the                   TimeOutAction is taken. Minimum value is 5 and maximum value is 1440. The timeout applies only during initial provisioning, when the cluster                   is first created                  # noqa: E501

        :return: The timeout_duration_minutes of this EmrClusterDefinitionSpotSpecification.  # noqa: E501
        :rtype: int
        """
        return self._timeout_duration_minutes

    @timeout_duration_minutes.setter
    def timeout_duration_minutes(self, timeout_duration_minutes):
        """Sets the timeout_duration_minutes of this EmrClusterDefinitionSpotSpecification.

        The spot provisioning timeout period in minutes. If Spot instances are not provisioned within this time period, the                   TimeOutAction is taken. Minimum value is 5 and maximum value is 1440. The timeout applies only during initial provisioning, when the cluster                   is first created                  # noqa: E501

        :param timeout_duration_minutes: The timeout_duration_minutes of this EmrClusterDefinitionSpotSpecification.  # noqa: E501
        :type: int
        """

        self._timeout_duration_minutes = timeout_duration_minutes

    @property
    def timeout_action(self):
        """Gets the timeout_action of this EmrClusterDefinitionSpotSpecification.  # noqa: E501

        The action to take when TargetSpotCapacity has not been fulfilled when the TimeoutDurationMinutes has expired. Spot instances                   are not uprovisioned within the Spot provisioining timeout. Valid values are TERMINATE_CLUSTER and SWITCH_TO_ON_DEMAND to fulfill the                   remaining capacity                  # noqa: E501

        :return: The timeout_action of this EmrClusterDefinitionSpotSpecification.  # noqa: E501
        :rtype: str
        """
        return self._timeout_action

    @timeout_action.setter
    def timeout_action(self, timeout_action):
        """Sets the timeout_action of this EmrClusterDefinitionSpotSpecification.

        The action to take when TargetSpotCapacity has not been fulfilled when the TimeoutDurationMinutes has expired. Spot instances                   are not uprovisioned within the Spot provisioining timeout. Valid values are TERMINATE_CLUSTER and SWITCH_TO_ON_DEMAND to fulfill the                   remaining capacity                  # noqa: E501

        :param timeout_action: The timeout_action of this EmrClusterDefinitionSpotSpecification.  # noqa: E501
        :type: str
        """

        self._timeout_action = timeout_action

    @property
    def block_duration_minutes(self):
        """Gets the block_duration_minutes of this EmrClusterDefinitionSpotSpecification.  # noqa: E501

        The defined duration for Spot instances (also known as Spot blocks) in minutes. When specified, the Spot instance does not                   terminate before the defined duration expires, and defined duration pricing for Spot instances applies. Valid values are 60, 120, 180, 240,                   300, or 360. The duration period starts as soon as a Spot instance receives its instance ID. At the end of the duration, Amazon EC2 marks the                   Spot instance for termination and provides a Spot instance termination notice, which gives the instance a two-minute warning before it                   terminates                  # noqa: E501

        :return: The block_duration_minutes of this EmrClusterDefinitionSpotSpecification.  # noqa: E501
        :rtype: int
        """
        return self._block_duration_minutes

    @block_duration_minutes.setter
    def block_duration_minutes(self, block_duration_minutes):
        """Sets the block_duration_minutes of this EmrClusterDefinitionSpotSpecification.

        The defined duration for Spot instances (also known as Spot blocks) in minutes. When specified, the Spot instance does not                   terminate before the defined duration expires, and defined duration pricing for Spot instances applies. Valid values are 60, 120, 180, 240,                   300, or 360. The duration period starts as soon as a Spot instance receives its instance ID. At the end of the duration, Amazon EC2 marks the                   Spot instance for termination and provides a Spot instance termination notice, which gives the instance a two-minute warning before it                   terminates                  # noqa: E501

        :param block_duration_minutes: The block_duration_minutes of this EmrClusterDefinitionSpotSpecification.  # noqa: E501
        :type: int
        """

        self._block_duration_minutes = block_duration_minutes

    @property
    def allocation_strategy(self):
        """Gets the allocation_strategy of this EmrClusterDefinitionSpotSpecification.  # noqa: E501

        Specifies the strategy to use in launching Spot instance fleets. Currently, the only option is \"capacity-optimized\" (the                   default), which launches instances from Spot instance pools with optimal capacity for the number of instances that are launching                  # noqa: E501

        :return: The allocation_strategy of this EmrClusterDefinitionSpotSpecification.  # noqa: E501
        :rtype: str
        """
        return self._allocation_strategy

    @allocation_strategy.setter
    def allocation_strategy(self, allocation_strategy):
        """Sets the allocation_strategy of this EmrClusterDefinitionSpotSpecification.

        Specifies the strategy to use in launching Spot instance fleets. Currently, the only option is \"capacity-optimized\" (the                   default), which launches instances from Spot instance pools with optimal capacity for the number of instances that are launching                  # noqa: E501

        :param allocation_strategy: The allocation_strategy of this EmrClusterDefinitionSpotSpecification.  # noqa: E501
        :type: str
        """

        self._allocation_strategy = allocation_strategy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmrClusterDefinitionSpotSpecification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.tag_type_api import TagTypeApi  # noqa: E501
from herdsdk.rest import ApiException


class TestTagTypeApi(unittest.TestCase):
    """TagTypeApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.tag_type_api.TagTypeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_tag_type_create_tag_type(self):
        """Test case for tag_type_create_tag_type

        createTagType  # noqa: E501
        """
        pass

    def test_tag_type_delete_tag_type(self):
        """Test case for tag_type_delete_tag_type

        deleteTagType  # noqa: E501
        """
        pass

    def test_tag_type_get_tag_type(self):
        """Test case for tag_type_get_tag_type

        getTagType  # noqa: E501
        """
        pass

    def test_tag_type_get_tag_types(self):
        """Test case for tag_type_get_tag_types

        getTagTypes  # noqa: E501
        """
        pass

    def test_tag_type_search_tag_types(self):
        """Test case for tag_type_search_tag_types

        searchTagTypes  # noqa: E501
        """
        pass

    def test_tag_type_update_tag_type(self):
        """Test case for tag_type_update_tag_type

        updateTagType  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectDefinitionCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'data_provider_name': 'str',
        'description': 'str',
        'display_name': 'str',
        'attributes': 'list[Attribute]'
    }

    attribute_map = {
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'data_provider_name': 'dataProviderName',
        'description': 'description',
        'display_name': 'displayName',
        'attributes': 'attributes'
    }

    def __init__(self, namespace=None, business_object_definition_name=None, data_provider_name=None, description=None, display_name=None, attributes=None):  # noqa: E501
        """BusinessObjectDefinitionCreateRequest - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._business_object_definition_name = None
        self._data_provider_name = None
        self._description = None
        self._display_name = None
        self._attributes = None
        self.discriminator = None

        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        self.data_provider_name = data_provider_name
        if description is not None:
            self.description = description
        if display_name is not None:
            self.display_name = display_name
        if attributes is not None:
            self.attributes = attributes

    @property
    def namespace(self):
        """Gets the namespace of this BusinessObjectDefinitionCreateRequest.  # noqa: E501

        The name of a valid Namespace known by the system  # noqa: E501

        :return: The namespace of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BusinessObjectDefinitionCreateRequest.

        The name of a valid Namespace known by the system  # noqa: E501

        :param namespace: The namespace of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501

        The name for this Business Object Definition  # noqa: E501

        :return: The business_object_definition_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this BusinessObjectDefinitionCreateRequest.

        The name for this Business Object Definition  # noqa: E501

        :param business_object_definition_name: The business_object_definition_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def data_provider_name(self):
        """Gets the data_provider_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501

        The name of a valid Data Provider known by the system  # noqa: E501

        :return: The data_provider_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._data_provider_name

    @data_provider_name.setter
    def data_provider_name(self, data_provider_name):
        """Sets the data_provider_name of this BusinessObjectDefinitionCreateRequest.

        The name of a valid Data Provider known by the system  # noqa: E501

        :param data_provider_name: The data_provider_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :type: str
        """
        if data_provider_name is None:
            raise ValueError("Invalid value for `data_provider_name`, must not be `None`")  # noqa: E501

        self._data_provider_name = data_provider_name

    @property
    def description(self):
        """Gets the description of this BusinessObjectDefinitionCreateRequest.  # noqa: E501

        An optional description  # noqa: E501

        :return: The description of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BusinessObjectDefinitionCreateRequest.

        An optional description  # noqa: E501

        :param description: The description of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_name(self):
        """Gets the display_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501

        An optional business friendly name  # noqa: E501

        :return: The display_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this BusinessObjectDefinitionCreateRequest.

        An optional business friendly name  # noqa: E501

        :param display_name: The display_name of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def attributes(self):
        """Gets the attributes of this BusinessObjectDefinitionCreateRequest.  # noqa: E501

        Custom user-defined metadata associated with this Business Object Definition. \"name\" is the attribute name (i.e. the key) and                   \"value\" is the attribute value                  # noqa: E501

        :return: The attributes of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :rtype: list[Attribute]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this BusinessObjectDefinitionCreateRequest.

        Custom user-defined metadata associated with this Business Object Definition. \"name\" is the attribute name (i.e. the key) and                   \"value\" is the attribute value                  # noqa: E501

        :param attributes: The attributes of this BusinessObjectDefinitionCreateRequest.  # noqa: E501
        :type: list[Attribute]
        """

        self._attributes = attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectDefinitionCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class UploadSingleInitiationResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source_business_object_data': 'BusinessObjectData',
        'target_business_object_data': 'BusinessObjectData',
        'file': 'file',
        'uuid': 'str',
        'aws_access_key': 'str',
        'aws_secret_key': 'str',
        'aws_session_token': 'str',
        'aws_session_expiration_time': 'datetime',
        'aws_kms_key_id': 'str',
        'target_storage_name': 'str'
    }

    attribute_map = {
        'source_business_object_data': 'sourceBusinessObjectData',
        'target_business_object_data': 'targetBusinessObjectData',
        'file': 'file',
        'uuid': 'uuid',
        'aws_access_key': 'awsAccessKey',
        'aws_secret_key': 'awsSecretKey',
        'aws_session_token': 'awsSessionToken',
        'aws_session_expiration_time': 'awsSessionExpirationTime',
        'aws_kms_key_id': 'awsKmsKeyId',
        'target_storage_name': 'targetStorageName'
    }

    def __init__(self, source_business_object_data=None, target_business_object_data=None, file=None, uuid=None, aws_access_key=None, aws_secret_key=None, aws_session_token=None, aws_session_expiration_time=None, aws_kms_key_id=None, target_storage_name=None):  # noqa: E501
        """UploadSingleInitiationResponse - a model defined in OpenAPI"""  # noqa: E501

        self._source_business_object_data = None
        self._target_business_object_data = None
        self._file = None
        self._uuid = None
        self._aws_access_key = None
        self._aws_secret_key = None
        self._aws_session_token = None
        self._aws_session_expiration_time = None
        self._aws_kms_key_id = None
        self._target_storage_name = None
        self.discriminator = None

        self.source_business_object_data = source_business_object_data
        self.target_business_object_data = target_business_object_data
        self.file = file
        self.uuid = uuid
        self.aws_access_key = aws_access_key
        self.aws_secret_key = aws_secret_key
        self.aws_session_token = aws_session_token
        self.aws_session_expiration_time = aws_session_expiration_time
        self.aws_kms_key_id = aws_kms_key_id
        self.target_storage_name = target_storage_name

    @property
    def source_business_object_data(self):
        """Gets the source_business_object_data of this UploadSingleInitiationResponse.  # noqa: E501


        :return: The source_business_object_data of this UploadSingleInitiationResponse.  # noqa: E501
        :rtype: BusinessObjectData
        """
        return self._source_business_object_data

    @source_business_object_data.setter
    def source_business_object_data(self, source_business_object_data):
        """Sets the source_business_object_data of this UploadSingleInitiationResponse.


        :param source_business_object_data: The source_business_object_data of this UploadSingleInitiationResponse.  # noqa: E501
        :type: BusinessObjectData
        """
        if source_business_object_data is None:
            raise ValueError("Invalid value for `source_business_object_data`, must not be `None`")  # noqa: E501

        self._source_business_object_data = source_business_object_data

    @property
    def target_business_object_data(self):
        """Gets the target_business_object_data of this UploadSingleInitiationResponse.  # noqa: E501


        :return: The target_business_object_data of this UploadSingleInitiationResponse.  # noqa: E501
        :rtype: BusinessObjectData
        """
        return self._target_business_object_data

    @target_business_object_data.setter
    def target_business_object_data(self, target_business_object_data):
        """Sets the target_business_object_data of this UploadSingleInitiationResponse.


        :param target_business_object_data: The target_business_object_data of this UploadSingleInitiationResponse.  # noqa: E501
        :type: BusinessObjectData
        """
        if target_business_object_data is None:
            raise ValueError("Invalid value for `target_business_object_data`, must not be `None`")  # noqa: E501

        self._target_business_object_data = target_business_object_data

    @property
    def file(self):
        """Gets the file of this UploadSingleInitiationResponse.  # noqa: E501


        :return: The file of this UploadSingleInitiationResponse.  # noqa: E501
        :rtype: file
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this UploadSingleInitiationResponse.


        :param file: The file of this UploadSingleInitiationResponse.  # noqa: E501
        :type: file
        """
        if file is None:
            raise ValueError("Invalid value for `file`, must not be `None`")  # noqa: E501

        self._file = file

    @property
    def uuid(self):
        """Gets the uuid of this UploadSingleInitiationResponse.  # noqa: E501

        The UUID generated for this upload  # noqa: E501

        :return: The uuid of this UploadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this UploadSingleInitiationResponse.

        The UUID generated for this upload  # noqa: E501

        :param uuid: The uuid of this UploadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if uuid is None:
            raise ValueError("Invalid value for `uuid`, must not be `None`")  # noqa: E501

        self._uuid = uuid

    @property
    def aws_access_key(self):
        """Gets the aws_access_key of this UploadSingleInitiationResponse.  # noqa: E501

        The AWS access key that must be used to upload to this object in S3  # noqa: E501

        :return: The aws_access_key of this UploadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._aws_access_key

    @aws_access_key.setter
    def aws_access_key(self, aws_access_key):
        """Sets the aws_access_key of this UploadSingleInitiationResponse.

        The AWS access key that must be used to upload to this object in S3  # noqa: E501

        :param aws_access_key: The aws_access_key of this UploadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if aws_access_key is None:
            raise ValueError("Invalid value for `aws_access_key`, must not be `None`")  # noqa: E501

        self._aws_access_key = aws_access_key

    @property
    def aws_secret_key(self):
        """Gets the aws_secret_key of this UploadSingleInitiationResponse.  # noqa: E501

        The AWS secret key that must be used to upload to this object in S3  # noqa: E501

        :return: The aws_secret_key of this UploadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._aws_secret_key

    @aws_secret_key.setter
    def aws_secret_key(self, aws_secret_key):
        """Sets the aws_secret_key of this UploadSingleInitiationResponse.

        The AWS secret key that must be used to upload to this object in S3  # noqa: E501

        :param aws_secret_key: The aws_secret_key of this UploadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if aws_secret_key is None:
            raise ValueError("Invalid value for `aws_secret_key`, must not be `None`")  # noqa: E501

        self._aws_secret_key = aws_secret_key

    @property
    def aws_session_token(self):
        """Gets the aws_session_token of this UploadSingleInitiationResponse.  # noqa: E501

        The AWS session token that must be used to upload to this object in S3  # noqa: E501

        :return: The aws_session_token of this UploadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._aws_session_token

    @aws_session_token.setter
    def aws_session_token(self, aws_session_token):
        """Sets the aws_session_token of this UploadSingleInitiationResponse.

        The AWS session token that must be used to upload to this object in S3  # noqa: E501

        :param aws_session_token: The aws_session_token of this UploadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if aws_session_token is None:
            raise ValueError("Invalid value for `aws_session_token`, must not be `None`")  # noqa: E501

        self._aws_session_token = aws_session_token

    @property
    def aws_session_expiration_time(self):
        """Gets the aws_session_expiration_time of this UploadSingleInitiationResponse.  # noqa: E501

        The timestamp of when the provided AWS credentials will expire  # noqa: E501

        :return: The aws_session_expiration_time of this UploadSingleInitiationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._aws_session_expiration_time

    @aws_session_expiration_time.setter
    def aws_session_expiration_time(self, aws_session_expiration_time):
        """Sets the aws_session_expiration_time of this UploadSingleInitiationResponse.

        The timestamp of when the provided AWS credentials will expire  # noqa: E501

        :param aws_session_expiration_time: The aws_session_expiration_time of this UploadSingleInitiationResponse.  # noqa: E501
        :type: datetime
        """
        if aws_session_expiration_time is None:
            raise ValueError("Invalid value for `aws_session_expiration_time`, must not be `None`")  # noqa: E501

        self._aws_session_expiration_time = aws_session_expiration_time

    @property
    def aws_kms_key_id(self):
        """Gets the aws_kms_key_id of this UploadSingleInitiationResponse.  # noqa: E501

        The KMS key ID that must be used to do SSE  # noqa: E501

        :return: The aws_kms_key_id of this UploadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._aws_kms_key_id

    @aws_kms_key_id.setter
    def aws_kms_key_id(self, aws_kms_key_id):
        """Sets the aws_kms_key_id of this UploadSingleInitiationResponse.

        The KMS key ID that must be used to do SSE  # noqa: E501

        :param aws_kms_key_id: The aws_kms_key_id of this UploadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if aws_kms_key_id is None:
            raise ValueError("Invalid value for `aws_kms_key_id`, must not be `None`")  # noqa: E501

        self._aws_kms_key_id = aws_kms_key_id

    @property
    def target_storage_name(self):
        """Gets the target_storage_name of this UploadSingleInitiationResponse.  # noqa: E501

        The target storage name  # noqa: E501

        :return: The target_storage_name of this UploadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._target_storage_name

    @target_storage_name.setter
    def target_storage_name(self, target_storage_name):
        """Sets the target_storage_name of this UploadSingleInitiationResponse.

        The target storage name  # noqa: E501

        :param target_storage_name: The target_storage_name of this UploadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if target_storage_name is None:
            raise ValueError("Invalid value for `target_storage_name`, must not be `None`")  # noqa: E501

        self._target_storage_name = target_storage_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UploadSingleInitiationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class MasterInstanceDefinition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'instance_count': 'int',
        'instance_type': 'str',
        'ebs_configuration': 'EmrClusterDefinitionEbsConfiguration',
        'instance_spot_price': 'float',
        'instance_max_search_price': 'float',
        'instance_on_demand_threshold': 'float'
    }

    attribute_map = {
        'instance_count': 'instanceCount',
        'instance_type': 'instanceType',
        'ebs_configuration': 'ebsConfiguration',
        'instance_spot_price': 'instanceSpotPrice',
        'instance_max_search_price': 'instanceMaxSearchPrice',
        'instance_on_demand_threshold': 'instanceOnDemandThreshold'
    }

    def __init__(self, instance_count=None, instance_type=None, ebs_configuration=None, instance_spot_price=None, instance_max_search_price=None, instance_on_demand_threshold=None):  # noqa: E501
        """MasterInstanceDefinition - a model defined in OpenAPI"""  # noqa: E501

        self._instance_count = None
        self._instance_type = None
        self._ebs_configuration = None
        self._instance_spot_price = None
        self._instance_max_search_price = None
        self._instance_on_demand_threshold = None
        self.discriminator = None

        if instance_count is not None:
            self.instance_count = instance_count
        self.instance_type = instance_type
        if ebs_configuration is not None:
            self.ebs_configuration = ebs_configuration
        if instance_spot_price is not None:
            self.instance_spot_price = instance_spot_price
        if instance_max_search_price is not None:
            self.instance_max_search_price = instance_max_search_price
        if instance_on_demand_threshold is not None:
            self.instance_on_demand_threshold = instance_on_demand_threshold

    @property
    def instance_count(self):
        """Gets the instance_count of this MasterInstanceDefinition.  # noqa: E501


        :return: The instance_count of this MasterInstanceDefinition.  # noqa: E501
        :rtype: int
        """
        return self._instance_count

    @instance_count.setter
    def instance_count(self, instance_count):
        """Sets the instance_count of this MasterInstanceDefinition.


        :param instance_count: The instance_count of this MasterInstanceDefinition.  # noqa: E501
        :type: int
        """

        self._instance_count = instance_count

    @property
    def instance_type(self):
        """Gets the instance_type of this MasterInstanceDefinition.  # noqa: E501


        :return: The instance_type of this MasterInstanceDefinition.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type):
        """Sets the instance_type of this MasterInstanceDefinition.


        :param instance_type: The instance_type of this MasterInstanceDefinition.  # noqa: E501
        :type: str
        """
        if instance_type is None:
            raise ValueError("Invalid value for `instance_type`, must not be `None`")  # noqa: E501

        self._instance_type = instance_type

    @property
    def ebs_configuration(self):
        """Gets the ebs_configuration of this MasterInstanceDefinition.  # noqa: E501


        :return: The ebs_configuration of this MasterInstanceDefinition.  # noqa: E501
        :rtype: EmrClusterDefinitionEbsConfiguration
        """
        return self._ebs_configuration

    @ebs_configuration.setter
    def ebs_configuration(self, ebs_configuration):
        """Sets the ebs_configuration of this MasterInstanceDefinition.


        :param ebs_configuration: The ebs_configuration of this MasterInstanceDefinition.  # noqa: E501
        :type: EmrClusterDefinitionEbsConfiguration
        """

        self._ebs_configuration = ebs_configuration

    @property
    def instance_spot_price(self):
        """Gets the instance_spot_price of this MasterInstanceDefinition.  # noqa: E501

        The instance bid price, in USD. If not specified, uses on-demand  # noqa: E501

        :return: The instance_spot_price of this MasterInstanceDefinition.  # noqa: E501
        :rtype: float
        """
        return self._instance_spot_price

    @instance_spot_price.setter
    def instance_spot_price(self, instance_spot_price):
        """Sets the instance_spot_price of this MasterInstanceDefinition.

        The instance bid price, in USD. If not specified, uses on-demand  # noqa: E501

        :param instance_spot_price: The instance_spot_price of this MasterInstanceDefinition.  # noqa: E501
        :type: float
        """

        self._instance_spot_price = instance_spot_price

    @property
    def instance_max_search_price(self):
        """Gets the instance_max_search_price of this MasterInstanceDefinition.  # noqa: E501

        The maximum amount, in USD, to search for the best price. The best price search will only search for prices lower than this                   value. If a spot instance is selected by the search, this value will be the bid price                  # noqa: E501

        :return: The instance_max_search_price of this MasterInstanceDefinition.  # noqa: E501
        :rtype: float
        """
        return self._instance_max_search_price

    @instance_max_search_price.setter
    def instance_max_search_price(self, instance_max_search_price):
        """Sets the instance_max_search_price of this MasterInstanceDefinition.

        The maximum amount, in USD, to search for the best price. The best price search will only search for prices lower than this                   value. If a spot instance is selected by the search, this value will be the bid price                  # noqa: E501

        :param instance_max_search_price: The instance_max_search_price of this MasterInstanceDefinition.  # noqa: E501
        :type: float
        """

        self._instance_max_search_price = instance_max_search_price

    @property
    def instance_on_demand_threshold(self):
        """Gets the instance_on_demand_threshold of this MasterInstanceDefinition.  # noqa: E501

        <p>The amount, in USD, you are willing to pay over the lowest spot price for an on-demand instance. Use this to                   dynamically balance the cost vs. stability of your instances.</p>                   <p>If not specified, the search will not attempt to find an on-demand instance when a spot is found. This is the same behavior as when                   this parameter is set to $0.</p>                  # noqa: E501

        :return: The instance_on_demand_threshold of this MasterInstanceDefinition.  # noqa: E501
        :rtype: float
        """
        return self._instance_on_demand_threshold

    @instance_on_demand_threshold.setter
    def instance_on_demand_threshold(self, instance_on_demand_threshold):
        """Sets the instance_on_demand_threshold of this MasterInstanceDefinition.

        <p>The amount, in USD, you are willing to pay over the lowest spot price for an on-demand instance. Use this to                   dynamically balance the cost vs. stability of your instances.</p>                   <p>If not specified, the search will not attempt to find an on-demand instance when a spot is found. This is the same behavior as when                   this parameter is set to $0.</p>                  # noqa: E501

        :param instance_on_demand_threshold: The instance_on_demand_threshold of this MasterInstanceDefinition.  # noqa: E501
        :type: float
        """

        self._instance_on_demand_threshold = instance_on_demand_threshold

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MasterInstanceDefinition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EmrClusterDefinitionApplication(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'version': 'str',
        'args': 'list[str]',
        'additional_info_list': 'list[Parameter]'
    }

    attribute_map = {
        'name': 'name',
        'version': 'version',
        'args': 'args',
        'additional_info_list': 'additionalInfoList'
    }

    def __init__(self, name=None, version=None, args=None, additional_info_list=None):  # noqa: E501
        """EmrClusterDefinitionApplication - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._version = None
        self._args = None
        self._additional_info_list = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if version is not None:
            self.version = version
        if args is not None:
            self.args = args
        if additional_info_list is not None:
            self.additional_info_list = additional_info_list

    @property
    def name(self):
        """Gets the name of this EmrClusterDefinitionApplication.  # noqa: E501

        Application name  # noqa: E501

        :return: The name of this EmrClusterDefinitionApplication.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EmrClusterDefinitionApplication.

        Application name  # noqa: E501

        :param name: The name of this EmrClusterDefinitionApplication.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def version(self):
        """Gets the version of this EmrClusterDefinitionApplication.  # noqa: E501

        Application version  # noqa: E501

        :return: The version of this EmrClusterDefinitionApplication.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this EmrClusterDefinitionApplication.

        Application version  # noqa: E501

        :param version: The version of this EmrClusterDefinitionApplication.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def args(self):
        """Gets the args of this EmrClusterDefinitionApplication.  # noqa: E501

        List of arguments  # noqa: E501

        :return: The args of this EmrClusterDefinitionApplication.  # noqa: E501
        :rtype: list[str]
        """
        return self._args

    @args.setter
    def args(self, args):
        """Sets the args of this EmrClusterDefinitionApplication.

        List of arguments  # noqa: E501

        :param args: The args of this EmrClusterDefinitionApplication.  # noqa: E501
        :type: list[str]
        """

        self._args = args

    @property
    def additional_info_list(self):
        """Gets the additional_info_list of this EmrClusterDefinitionApplication.  # noqa: E501

        List of additional info  # noqa: E501

        :return: The additional_info_list of this EmrClusterDefinitionApplication.  # noqa: E501
        :rtype: list[Parameter]
        """
        return self._additional_info_list

    @additional_info_list.setter
    def additional_info_list(self, additional_info_list):
        """Sets the additional_info_list of this EmrClusterDefinitionApplication.

        List of additional info  # noqa: E501

        :param additional_info_list: The additional_info_list of this EmrClusterDefinitionApplication.  # noqa: E501
        :type: list[Parameter]
        """

        self._additional_info_list = additional_info_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmrClusterDefinitionApplication):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.external_interface_api import ExternalInterfaceApi  # noqa: E501
from herdsdk.rest import ApiException


class TestExternalInterfaceApi(unittest.TestCase):
    """ExternalInterfaceApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.external_interface_api.ExternalInterfaceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_external_interface_create_external_interface(self):
        """Test case for external_interface_create_external_interface

        createExternalInterface  # noqa: E501
        """
        pass

    def test_external_interface_delete_external_interface(self):
        """Test case for external_interface_delete_external_interface

        deleteExternalInterface  # noqa: E501
        """
        pass

    def test_external_interface_get_external_interface(self):
        """Test case for external_interface_get_external_interface

        getExternalInterface  # noqa: E501
        """
        pass

    def test_external_interface_get_external_interfaces(self):
        """Test case for external_interface_get_external_interfaces

        getExternalInterfaces  # noqa: E501
        """
        pass

    def test_external_interface_update_external_interface(self):
        """Test case for external_interface_update_external_interface

        updateExternalInterface  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.file_type_api import FileTypeApi  # noqa: E501
from herdsdk.rest import ApiException


class TestFileTypeApi(unittest.TestCase):
    """FileTypeApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.file_type_api.FileTypeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_file_type_create_file_type(self):
        """Test case for file_type_create_file_type

        createFileType  # noqa: E501
        """
        pass

    def test_file_type_delete_file_type(self):
        """Test case for file_type_delete_file_type

        deleteFileType  # noqa: E501
        """
        pass

    def test_file_type_get_file_type(self):
        """Test case for file_type_get_file_type

        getFileType  # noqa: E501
        """
        pass

    def test_file_type_get_file_types(self):
        """Test case for file_type_get_file_types

        getFileTypes  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.storage_policy_api import StoragePolicyApi  # noqa: E501
from herdsdk.rest import ApiException


class TestStoragePolicyApi(unittest.TestCase):
    """StoragePolicyApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.storage_policy_api.StoragePolicyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_storage_policy_create_storage_policy(self):
        """Test case for storage_policy_create_storage_policy

        createStoragePolicy  # noqa: E501
        """
        pass

    def test_storage_policy_delete_storage_policy(self):
        """Test case for storage_policy_delete_storage_policy

        deleteStoragePolicy  # noqa: E501
        """
        pass

    def test_storage_policy_get_storage_policy(self):
        """Test case for storage_policy_get_storage_policy

        getStoragePolicy  # noqa: E501
        """
        pass

    def test_storage_policy_get_storage_policy_keys(self):
        """Test case for storage_policy_get_storage_policy_keys

        getStoragePolicyKeys  # noqa: E501
        """
        pass

    def test_storage_policy_update_storage_policy(self):
        """Test case for storage_policy_update_storage_policy

        updateStoragePolicy  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.tag_api import TagApi  # noqa: E501
from herdsdk.rest import ApiException


class TestTagApi(unittest.TestCase):
    """TagApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.tag_api.TagApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_tag_create_tag(self):
        """Test case for tag_create_tag

        createTag  # noqa: E501
        """
        pass

    def test_tag_delete_tag(self):
        """Test case for tag_delete_tag

        deleteTag  # noqa: E501
        """
        pass

    def test_tag_get_tag(self):
        """Test case for tag_get_tag

        getTag  # noqa: E501
        """
        pass

    def test_tag_get_tags(self):
        """Test case for tag_get_tags

        getTags  # noqa: E501
        """
        pass

    def test_tag_search_tags(self):
        """Test case for tag_search_tags

        searchTags  # noqa: E501
        """
        pass

    def test_tag_update_tag(self):
        """Test case for tag_update_tag

        updateTag  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class ErrorInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status_code': 'int',
        'status_description': 'str',
        'message': 'str',
        'message_details': 'list[str]'
    }

    attribute_map = {
        'status_code': 'statusCode',
        'status_description': 'statusDescription',
        'message': 'message',
        'message_details': 'messageDetails'
    }

    def __init__(self, status_code=None, status_description=None, message=None, message_details=None):  # noqa: E501
        """ErrorInformation - a model defined in OpenAPI"""  # noqa: E501

        self._status_code = None
        self._status_description = None
        self._message = None
        self._message_details = None
        self.discriminator = None

        if status_code is not None:
            self.status_code = status_code
        self.status_description = status_description
        self.message = message
        if message_details is not None:
            self.message_details = message_details

    @property
    def status_code(self):
        """Gets the status_code of this ErrorInformation.  # noqa: E501


        :return: The status_code of this ErrorInformation.  # noqa: E501
        :rtype: int
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this ErrorInformation.


        :param status_code: The status_code of this ErrorInformation.  # noqa: E501
        :type: int
        """

        self._status_code = status_code

    @property
    def status_description(self):
        """Gets the status_description of this ErrorInformation.  # noqa: E501


        :return: The status_description of this ErrorInformation.  # noqa: E501
        :rtype: str
        """
        return self._status_description

    @status_description.setter
    def status_description(self, status_description):
        """Sets the status_description of this ErrorInformation.


        :param status_description: The status_description of this ErrorInformation.  # noqa: E501
        :type: str
        """
        if status_description is None:
            raise ValueError("Invalid value for `status_description`, must not be `None`")  # noqa: E501

        self._status_description = status_description

    @property
    def message(self):
        """Gets the message of this ErrorInformation.  # noqa: E501


        :return: The message of this ErrorInformation.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ErrorInformation.


        :param message: The message of this ErrorInformation.  # noqa: E501
        :type: str
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def message_details(self):
        """Gets the message_details of this ErrorInformation.  # noqa: E501


        :return: The message_details of this ErrorInformation.  # noqa: E501
        :rtype: list[str]
        """
        return self._message_details

    @message_details.setter
    def message_details(self, message_details):
        """Sets the message_details of this ErrorInformation.


        :param message_details: The message_details of this ErrorInformation.  # noqa: E501
        :type: list[str]
        """

        self._message_details = message_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Storage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'storage_platform_name': 'str',
        'attributes': 'list[Attribute]'
    }

    attribute_map = {
        'name': 'name',
        'storage_platform_name': 'storagePlatformName',
        'attributes': 'attributes'
    }

    def __init__(self, name=None, storage_platform_name=None, attributes=None):  # noqa: E501
        """Storage - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._storage_platform_name = None
        self._attributes = None
        self.discriminator = None

        self.name = name
        self.storage_platform_name = storage_platform_name
        if attributes is not None:
            self.attributes = attributes

    @property
    def name(self):
        """Gets the name of this Storage.  # noqa: E501

        Name of Storage  # noqa: E501

        :return: The name of this Storage.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Storage.

        Name of Storage  # noqa: E501

        :param name: The name of this Storage.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def storage_platform_name(self):
        """Gets the storage_platform_name of this Storage.  # noqa: E501

        Name of Storage Platform (eg S3) associated with this Storage  # noqa: E501

        :return: The storage_platform_name of this Storage.  # noqa: E501
        :rtype: str
        """
        return self._storage_platform_name

    @storage_platform_name.setter
    def storage_platform_name(self, storage_platform_name):
        """Sets the storage_platform_name of this Storage.

        Name of Storage Platform (eg S3) associated with this Storage  # noqa: E501

        :param storage_platform_name: The storage_platform_name of this Storage.  # noqa: E501
        :type: str
        """
        if storage_platform_name is None:
            raise ValueError("Invalid value for `storage_platform_name`, must not be `None`")  # noqa: E501

        self._storage_platform_name = storage_platform_name

    @property
    def attributes(self):
        """Gets the attributes of this Storage.  # noqa: E501

        Collection of name-value pairs. This can be used to store things such as S3 bucket names, validation flags, and custom                   user-defined meta-data about this storage                  # noqa: E501

        :return: The attributes of this Storage.  # noqa: E501
        :rtype: list[Attribute]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this Storage.

        Collection of name-value pairs. This can be used to store things such as S3 bucket names, validation flags, and custom                   user-defined meta-data about this storage                  # noqa: E501

        :param attributes: The attributes of this Storage.  # noqa: E501
        :type: list[Attribute]
        """

        self._attributes = attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Storage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class IndexSearchRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'search_term': 'str',
        'index_search_filters': 'list[IndexSearchFilter]',
        'facet_fields': 'list[str]',
        'enable_hit_highlighting': 'bool'
    }

    attribute_map = {
        'search_term': 'searchTerm',
        'index_search_filters': 'indexSearchFilters',
        'facet_fields': 'facetFields',
        'enable_hit_highlighting': 'enableHitHighlighting'
    }

    def __init__(self, search_term=None, index_search_filters=None, facet_fields=None, enable_hit_highlighting=None):  # noqa: E501
        """IndexSearchRequest - a model defined in OpenAPI"""  # noqa: E501

        self._search_term = None
        self._index_search_filters = None
        self._facet_fields = None
        self._enable_hit_highlighting = None
        self.discriminator = None

        if search_term is not None:
            self.search_term = search_term
        if index_search_filters is not None:
            self.index_search_filters = index_search_filters
        if facet_fields is not None:
            self.facet_fields = facet_fields
        if enable_hit_highlighting is not None:
            self.enable_hit_highlighting = enable_hit_highlighting

    @property
    def search_term(self):
        """Gets the search_term of this IndexSearchRequest.  # noqa: E501

        The search term upon which to search  # noqa: E501

        :return: The search_term of this IndexSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._search_term

    @search_term.setter
    def search_term(self, search_term):
        """Sets the search_term of this IndexSearchRequest.

        The search term upon which to search  # noqa: E501

        :param search_term: The search_term of this IndexSearchRequest.  # noqa: E501
        :type: str
        """

        self._search_term = search_term

    @property
    def index_search_filters(self):
        """Gets the index_search_filters of this IndexSearchRequest.  # noqa: E501

        A list of index search filters. Multiple filters are supported which are AND-ed  # noqa: E501

        :return: The index_search_filters of this IndexSearchRequest.  # noqa: E501
        :rtype: list[IndexSearchFilter]
        """
        return self._index_search_filters

    @index_search_filters.setter
    def index_search_filters(self, index_search_filters):
        """Sets the index_search_filters of this IndexSearchRequest.

        A list of index search filters. Multiple filters are supported which are AND-ed  # noqa: E501

        :param index_search_filters: The index_search_filters of this IndexSearchRequest.  # noqa: E501
        :type: list[IndexSearchFilter]
        """

        self._index_search_filters = index_search_filters

    @property
    def facet_fields(self):
        """Gets the facet_fields of this IndexSearchRequest.  # noqa: E501

        A list of Facet Fields to be included with the response. Only Tag and ResultType facet information is supported                  # noqa: E501

        :return: The facet_fields of this IndexSearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._facet_fields

    @facet_fields.setter
    def facet_fields(self, facet_fields):
        """Sets the facet_fields of this IndexSearchRequest.

        A list of Facet Fields to be included with the response. Only Tag and ResultType facet information is supported                  # noqa: E501

        :param facet_fields: The facet_fields of this IndexSearchRequest.  # noqa: E501
        :type: list[str]
        """

        self._facet_fields = facet_fields

    @property
    def enable_hit_highlighting(self):
        """Gets the enable_hit_highlighting of this IndexSearchRequest.  # noqa: E501

        An optional boolean flag that specifies if highlighting should be enabled on the matched terms or not                  # noqa: E501

        :return: The enable_hit_highlighting of this IndexSearchRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enable_hit_highlighting

    @enable_hit_highlighting.setter
    def enable_hit_highlighting(self, enable_hit_highlighting):
        """Sets the enable_hit_highlighting of this IndexSearchRequest.

        An optional boolean flag that specifies if highlighting should be enabled on the matched terms or not                  # noqa: E501

        :param enable_hit_highlighting: The enable_hit_highlighting of this IndexSearchRequest.  # noqa: E501
        :type: bool
        """

        self._enable_hit_highlighting = enable_hit_highlighting

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IndexSearchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
